@@ -17,6 +17,8 @@ the Free Software Foundation, either version 3 of the License, or
 class MainWindow;
 class ProjectManager;
 class MonitorManager;
+class BinController;
+class Bin;
 
 #define pCore Core::self()
 
@@ -52,7 +54,11 @@ public:
     ProjectManager *projectManager();
     /** @brief Returns a pointer to the monitor manager. */
     MonitorManager *monitorManager();
+    /** @brief Returns a pointer to the project bin controller. */
+    BinController *binController();
 
+    Bin *bin();
+    
 private:
     explicit Core(MainWindow *mainWindow);
     static Core *m_self;
@@ -64,6 +70,11 @@ private:
     MainWindow *m_mainWindow;
     ProjectManager *m_projectManager;
     MonitorManager *m_monitorManager;
+    BinController *m_binController;
+    Bin *m_binWidget;
+
+signals:
+    void coreIsReady();
 };
 
 #endif
