@@ -23,6 +23,8 @@
 #include "definitions.h"
 #include "effectslist/initeffects.h"
 #include "mainwindow.h"
+#include "core.h"
+#include "mltcontroller/bincontroller.h"
 
 #include <QDebug>
 #include <KMessageBox>
@@ -37,6 +39,10 @@
 #include <mlt++/Mlt.h>
 
 #include <locale>
+#ifdef Q_OS_MAC
+#include <xlocale.h>
+#endif
+
 #include <QStandardPaths>
 
 
@@ -54,10 +60,6 @@ bool DocumentValidator::validate(const double currentVersion)
         return false;
 
     QDomElement kdenliveDoc = mlt.firstChildElement("kdenlivedoc");
-    // Check if we're validating a Kdenlive project
-    if (kdenliveDoc.isNull())
-        return false;
-    
     QString rootDir = mlt.attribute("root");
     if (rootDir == "$CURRENTPATH") {
         // The document was extracted from a Kdenlive archived project, fix root directory
@@ -72,8 +74,12 @@ bool DocumentValidator::validate(const double currentVersion)
     QLocale documentLocale = QLocale::c();
     
     if (mlt.hasAttribute("LC_NUMERIC")) {
-        // Set locale for the document        
+        // Set locale for the document
+#ifndef Q_OS_MAC
         const QString newLocale = setlocale(LC_NUMERIC, mlt.attribute("LC_NUMERIC").toUtf8().constData());
+#else
+        const QString newLocale = setlocale(LC_NUMERIC_MASK, mlt.attribute("LC_NUMERIC").toUtf8().constData());
+#endif
         documentLocale = QLocale(mlt.attribute("LC_NUMERIC"));
 
         // Make sure Qt locale and C++ locale have the same numeric separator, might not be the case
@@ -97,38 +103,52 @@ bool DocumentValidator::validate(const double currentVersion)
     if (documentLocale.decimalPoint() != QLocale().decimalPoint()) {
         // If loading an older MLT file without LC_NUMERIC, set locale to C which was previously the default
         if (!mlt.hasAttribute("LC_NUMERIC")) {
-	    setlocale(LC_NUMERIC, "C");
+#ifndef Q_OS_MAC
+            setlocale(LC_NUMERIC, "C");
+#else
+            setlocale(LC_NUMERIC_MASK, "C");
+#endif
 	}
 
         QLocale::setDefault(documentLocale);
         // locale conversion might need to be redone
-        initEffects::parseEffectFiles(setlocale(LC_NUMERIC, NULL));
+#ifndef Q_OS_MAC
+        initEffects::parseEffectFiles(pCore->binController()->mltRepository(), setlocale(LC_NUMERIC, NULL));
+#else
+        initEffects::parseEffectFiles(pCore->binController()->mltRepository(), setlocale(LC_NUMERIC_MASK, NULL));
+#endif
     }
-
-    bool ok;
-    double version = documentLocale.toDouble(kdenliveDoc.attribute("version"), &ok);
-    if (!ok) {
-	// Could not parse version number, there is probably a conflict in decimal separator
-	QLocale tempLocale = QLocale(mlt.attribute("LC_NUMERIC"));
-	version = tempLocale.toDouble(kdenliveDoc.attribute("version"), &ok);
-	if (!ok) version = kdenliveDoc.attribute("version").toDouble(&ok);
-	if (!ok) {
-	    // Last try: replace comma with a dot
-	    QString versionString = kdenliveDoc.attribute("version");
-	    if (versionString.contains(',')) versionString.replace(',', '.');
-	    version = versionString.toDouble(&ok);
-	    if (!ok) qDebug()<<"// CANNOT PARSE VERSION NUMBER, ERROR!";
-	}
+    double version = -1;
+    if (kdenliveDoc.isNull() || !kdenliveDoc.hasAttribute("version")) {
+        // Newer Kdenlive document version
+        QDomElement main = mlt.firstChildElement("playlist");
+        version = EffectsList::property(main, "kdenlive:docproperties.version").toDouble();
+    }
+    else {
+        bool ok;
+        version = documentLocale.toDouble(kdenliveDoc.attribute("version"), &ok);
+        if (!ok) {
+            // Could not parse version number, there is probably a conflict in decimal separator
+            QLocale tempLocale = QLocale(mlt.attribute("LC_NUMERIC"));
+            version = tempLocale.toDouble(kdenliveDoc.attribute("version"), &ok);
+            if (!ok) version = kdenliveDoc.attribute("version").toDouble(&ok);
+            if (!ok) {
+                // Last try: replace comma with a dot
+                QString versionString = kdenliveDoc.attribute("version");
+                if (versionString.contains(',')) versionString.replace(',', '.');
+                version = versionString.toDouble(&ok);
+                if (!ok) qDebug()<<"// CANNOT PARSE VERSION NUMBER, ERROR!";
+            }
+        }
     }
-    
     // Upgrade the document to the latest version
     if (!upgrade(version, currentVersion))
         return false;
 
+    return true;
     /*
-     * Check the syntax (this will be replaced by XSD validation with Qt 4.6)
-     * and correct some errors
-     */
+    // Check the syntax (this will be replaced by XSD validation with Qt 4.6)
+    // and correct some errors
     {
         // Return (or create) the tractor
         QDomElement tractor = mlt.firstChildElement("tractor");
@@ -142,21 +162,34 @@ bool DocumentValidator::validate(const double currentVersion)
             mlt.appendChild(tractor);
         }
 
-        /*
-         * Make sure at least one track exists, and they're equal in number to
-         * to the maximum between MLT and Kdenlive playlists and tracks
-         */
+        // Make sure at least one track exists, and they're equal in number to
+        // to the maximum between MLT and Kdenlive playlists and tracks
+        //
+        // In older Kdenlive project files, one playlist is not a real track (the black track), we have: track count = playlist count- 1
+        // In newer Qt5 Kdenlive, the Bin playlist should not appear as a track. So we should have: track count = playlist count- 2
+        int trackOffset = 1;
         QDomNodeList playlists = m_doc.elementsByTagName("playlist");
-        int tracksMax = playlists.count() - 1; // Remove the black track
+	// Remove "main bin" playlist that simply holds the bin's clips and is not a real playlist
+	for (int i = 0; i < playlists.count(); ++i) {
+	    QString playlistId = playlists.at(i).toElement().attribute("id");
+	    if (playlistId == BinController::binPlaylistId()) {
+		// remove pseudo-playlist
+		//playlists.at(i).parentNode().removeChild(playlists.at(i));
+                trackOffset = 2;
+		break;
+	    }
+	}
+	
+        int tracksMax = playlists.count() - trackOffset; // Remove the black track and bin track
         QDomNodeList tracks = tractor.elementsByTagName("track");
         tracksMax = qMax(tracks.count() - 1, tracksMax);
         QDomNodeList tracksinfo = kdenliveDoc.elementsByTagName("trackinfo");
         tracksMax = qMax(tracksinfo.count(), tracksMax);
         tracksMax = qMax(1, tracksMax); // Force existence of one track
-        if (playlists.count() - 1 < tracksMax ||
-                tracks.count() - 1 < tracksMax ||
+        if (playlists.count() - trackOffset < tracksMax ||
+                tracks.count() < tracksMax ||
                 tracksinfo.count() < tracksMax) {
-            //qDebug() << "//// WARNING, PROJECT IS CORRUPTED, MISSING TRACK";
+            qDebug() << "//// WARNING, PROJECT IS CORRUPTED, MISSING TRACK";
             m_modified = true;
             int difference;
             // use the MLT tracks as reference
@@ -218,21 +251,20 @@ bool DocumentValidator::validate(const double currentVersion)
                     tracksinfoElm.appendChild(trackinfo);
                 }
             }
-        }        
-
+        }
         // TODO: check the tracks references
         // TODO: check internal mix transitions
-        
     }
 
     updateEffects();
 
     return true;
+    */
 }
 
 bool DocumentValidator::upgrade(double version, const double currentVersion)
 {
-    //qDebug() << "Opening a document with version " << version;
+    qDebug() << "Opening a document with version " << version << " / "<<currentVersion;
 
     // No conversion needed
     if (version == currentVersion) {
@@ -254,9 +286,15 @@ bool DocumentValidator::upgrade(double version, const double currentVersion)
     }
 
     // <kdenlivedoc />
-    QDomNode infoXmlNode = m_doc.elementsByTagName("kdenlivedoc").at(0);
-    QDomElement infoXml = infoXmlNode.toElement();
-    infoXml.setAttribute("upgraded", "1");
+    QDomNode infoXmlNode;
+    QDomElement infoXml;
+    QDomNodeList docs = m_doc.elementsByTagName("kdenlivedoc");
+    if (!docs.isEmpty()) {
+        infoXmlNode = m_doc.elementsByTagName("kdenlivedoc").at(0);
+        infoXml = infoXmlNode.toElement();
+        infoXml.setAttribute("upgraded", "1");
+    }
+    m_doc.documentElement().setAttribute("upgraded", "1");
 
     if (version <= 0.6) {
         QDomElement infoXml_old = infoXmlNode.cloneNode(true).toElement(); // Needed for folders
@@ -967,9 +1005,257 @@ bool DocumentValidator::upgrade(double version, const double currentVersion)
             m_doc.firstChildElement("mlt").setAttribute("LC_NUMERIC", "C");
         }
     }
+    
+    if (version <= 0.88) {
+        // convert to new MLT-only format
+        QDomNodeList producers = m_doc.elementsByTagName("producer");
+        QDomDocumentFragment frag = m_doc.createDocumentFragment();
+        
+        // Create Bin Playlist
+        QDomElement main_playlist = m_doc.createElement("playlist");
+        main_playlist.setAttribute("id", "main bin");
+        QDomElement prop = m_doc.createElement("property");
+        prop.setAttribute("name", "xml_retain");
+        QDomText val = m_doc.createTextNode("1");
+        prop.appendChild(val);
+        main_playlist.appendChild(prop);
 
-    // The document has been converted: mark it as modified
-    infoXml.setAttribute("version", currentVersion);
+        // Move markers
+        QDomNodeList markers = m_doc.elementsByTagName("marker");
+        for (int i = 0; i < markers.count(); ++i) {
+            QDomElement marker = markers.at(i).toElement();
+            QDomElement prop = m_doc.createElement("property");
+            prop.setAttribute("name", "kdenlive:marker." + marker.attribute("id") + ":" + marker.attribute("time"));
+            QDomText val = m_doc.createTextNode(marker.attribute("type") + ":" + marker.attribute("comment"));
+            prop.appendChild(val);
+            main_playlist.appendChild(prop);
+        }
+
+        // Move guides
+        QDomNodeList guides = m_doc.elementsByTagName("guide");
+        for (int i = 0; i < guides.count(); ++i) {
+            QDomElement guide = guides.at(i).toElement();
+            QDomElement prop = m_doc.createElement("property");
+            prop.setAttribute("name", "kdenlive:guide." + guide.attribute("time"));
+            QDomText val = m_doc.createTextNode(guide.attribute("comment"));
+            prop.appendChild(val);
+            main_playlist.appendChild(prop);
+        }
+        
+        // Move folders
+        QDomNodeList folders = m_doc.elementsByTagName("folder");
+        for (int i = 0; i < folders.count(); ++i) {
+            QDomElement folder = folders.at(i).toElement();
+            QDomElement prop = m_doc.createElement("property");
+            prop.setAttribute("name", "kdenlive:folder.-1." + folder.attribute("id"));
+            QDomText val = m_doc.createTextNode(folder.attribute("name"));
+            prop.appendChild(val);
+            main_playlist.appendChild(prop);
+        }
+
+        QDomNode mlt = m_doc.firstChildElement("mlt");
+        main_playlist.setAttribute("id", pCore->binController()->binPlaylistId());
+        mlt.toElement().setAttribute("producer", pCore->binController()->binPlaylistId());
+        QStringList ids;
+        QStringList slowmotionIds;
+        QDomNode firstProd = m_doc.firstChildElement("producer");
+        for (int i = 0; i < producers.count(); ++i) {
+            QDomElement prod = producers.at(i).toElement();
+            QString id = prod.attribute("id");
+            if (id.startsWith("slowmotion")) {
+                // No need to process slowmotion producers
+                QString slowmo = id.section(":", 1, 1).section("_", 0, 0);
+                if (!slowmotionIds.contains(slowmo)) {
+                    slowmotionIds << slowmo;
+                }
+                continue;
+            }
+            QString prodId = id.section("_", 0, 0);
+            if (ids.contains(prodId)) {
+                // Already processed, continue
+                continue;
+            }
+            if (id == prodId) {
+                // This is an original producer, move it to the main playlist
+                QDomElement entry = m_doc.createElement("entry");
+                entry.setAttribute("in", prod.attribute("in"));
+                entry.setAttribute("out", prod.attribute("out"));
+                entry.setAttribute("producer", id);
+                main_playlist.appendChild(entry);
+                frag.appendChild(prod);
+                i--;
+            }
+            else {
+                QDomElement originalProd = prod.cloneNode().toElement();
+                originalProd.setAttribute("id", prodId);
+                frag.appendChild(originalProd);
+                QDomElement entry = m_doc.createElement("entry");
+                entry.setAttribute("in", prod.attribute("in"));
+                entry.setAttribute("out", prod.attribute("out"));
+                entry.setAttribute("producer", prodId);
+                main_playlist.appendChild(entry);
+            }
+            ids.append(prodId);
+        }
+
+        // Set clip folders
+        QDomNodeList kdenlive_producers = m_doc.elementsByTagName("kdenlive_producer");
+        for (int j = 0; j < kdenlive_producers.count(); j++) {
+            QDomElement prod = kdenlive_producers.at(j).toElement();
+            QString prodName = prod.attribute("name");
+            QString prodHash = prod.attribute("file_hash");
+            QString prodSize = prod.attribute("file_size");
+            QString id = prod.attribute("id");
+            QString folder = prod.attribute("groupid");
+            QDomNodeList mlt_producers = frag.childNodes();
+            for (int k = 0; k < mlt_producers.count(); k++) {
+                QDomElement mltprod = mlt_producers.at(k).toElement();
+                if (mltprod.tagName() != "producer") continue;
+                if (mltprod.attribute("id") == id) {
+                    if (!folder.isEmpty()) {
+                        // We have found our producer, set folder info
+                        QDomElement prop = m_doc.createElement("property");
+                        prop.setAttribute("name", "kdenlive:folderid");
+                        QDomText val = m_doc.createTextNode(folder);
+                        prop.appendChild(val);
+                        mltprod.appendChild(prop);
+                    }
+                    if (!prodName.isEmpty()) {
+                        // Set clip name
+                        QDomElement prop = m_doc.createElement("property");
+                        prop.setAttribute("name", "kdenlive:clipname");
+                        QDomText val = m_doc.createTextNode(prodName);
+                        prop.appendChild(val);
+                        mltprod.appendChild(prop);
+                    }
+                    if (!prodHash.isEmpty()) {
+                        // Set clip name
+                        QDomElement prop = m_doc.createElement("property");
+                        prop.setAttribute("name", "kdenlive:file_hash");
+                        QDomText val = m_doc.createTextNode(prodHash);
+                        prop.appendChild(val);
+                        mltprod.appendChild(prop);
+                    }
+                    if (!prodSize.isEmpty()) {
+                        // Set clip name
+                        QDomElement prop = m_doc.createElement("property");
+                        prop.setAttribute("name", "kdenlive:file_size");
+                        QDomText val = m_doc.createTextNode(prodSize);
+                        prop.appendChild(val);
+                        mltprod.appendChild(prop);
+                    }
+                    break;
+                }
+            }
+        }
+        
+        // Make sure all slowmotion producers have a master clip
+        for (int i = 0; i < slowmotionIds.count(); i++) {
+            QString slo = slowmotionIds.at(i);
+            if (!ids.contains(slo)) {
+                // rebuild producer from Kdenlive's old xml format
+                for (int j = 0; j < kdenlive_producers.count(); j++) {
+                    QDomElement prod = kdenlive_producers.at(j).toElement();
+                    QString id = prod.attribute("id");
+                    if (id == slo) {
+                        // We found the kdenlive_producer, build MLT producer
+                        QDomElement original = m_doc.createElement("producer");
+                        original.setAttribute("in", 0);
+                        original.setAttribute("out", prod.attribute("duration").toInt() - 1);
+                        original.setAttribute("id", id);
+                        QDomElement prop = m_doc.createElement("property");
+                        prop.setAttribute("name", "resource");
+                        QDomText val = m_doc.createTextNode(prod.attribute("resource"));
+                        prop.appendChild(val);
+                        original.appendChild(prop);
+                        QDomElement prop2 = m_doc.createElement("property");
+                        prop2.setAttribute("name", "mlt_service");
+                        QDomText val2 = m_doc.createTextNode("avformat");
+                        prop2.appendChild(val2);
+                        original.appendChild(prop2);
+                        QDomElement prop3 = m_doc.createElement("property");
+                        prop3.setAttribute("name", "length");
+                        QDomText val3 = m_doc.createTextNode(prod.attribute("duration"));
+                        prop3.appendChild(val3);
+                        original.appendChild(prop3);
+                        QDomElement entry = m_doc.createElement("entry");
+                        entry.setAttribute("in", original.attribute("in"));
+                        entry.setAttribute("out", original.attribute("out"));
+                        entry.setAttribute("producer", id);
+                        main_playlist.appendChild(entry);
+                        frag.appendChild(original);
+                        ids << slo;
+                        break;
+                    }
+                }
+            }
+        }
+        frag.appendChild(main_playlist);
+        mlt.insertBefore(frag, firstProd);
+    }
+    
+    if (version < 0.91) {
+        // Migrate track properties
+        QDomNodeList old_tracks = m_doc.elementsByTagName("trackinfo");
+        QDomNodeList tracks = m_doc.elementsByTagName("track");
+        QDomNodeList playlists = m_doc.elementsByTagName("playlist");
+        for (int i = 0; i < old_tracks.count(); i++) {
+            QString playlistName = tracks.at(i + 1).toElement().attribute("producer");
+            // find playlist for track
+            QDomElement trackPlaylist;
+            for (int j = 0; j < playlists.count(); j++) {
+                if (playlists.at(j).toElement().attribute("id") == playlistName) {
+                    trackPlaylist = playlists.at(j).toElement();
+                    break;
+                }
+            }
+            if (!trackPlaylist.isNull()) {
+                QDomElement kdenliveTrack = old_tracks.at(i).toElement();
+                if (kdenliveTrack.attribute("type") == "audio") {
+                    qDebug()<<"Found AUDIO TK";
+                    EffectsList::setProperty(trackPlaylist, "kdenlive:audio_track", "1");
+                }
+                if (kdenliveTrack.attribute("locked") == "1") {
+                    EffectsList::setProperty(trackPlaylist, "kdenlive:locked_track", "1");
+                }
+                EffectsList::setProperty(trackPlaylist, "kdenlive:track_name", kdenliveTrack.attribute("trackname"));
+            }
+        }
+        // Find bin playlist
+        playlists = m_doc.elementsByTagName("playlist");
+        QDomElement playlist;
+        for (int i = 0; i < playlists.count(); i++) {
+            if (playlists.at(i).toElement().attribute("id") == "main bin") {
+                playlist = playlists.at(i).toElement();
+                break;
+            }
+        }
+        // Migrate document notes
+        QDomNodeList notesList = m_doc.elementsByTagName("documentnotes");
+        if (!notesList.isEmpty()) {
+            QDomElement notes_elem = notesList.at(0).toElement();
+            QString notes = notes_elem.firstChild().nodeValue();
+            EffectsList::setProperty(playlist, "kdenlive:documentnotes", notes);
+        }
+        // Migrate clip groups
+        QDomNodeList groupElement = m_doc.elementsByTagName("groups");
+        if (!groupElement.isEmpty()) {
+            QDomElement groups = groupElement.at(0).toElement();
+            QDomDocument d2;
+            d2.importNode(groups, true);
+            EffectsList::setProperty(playlist, "kdenlive:clipgroups", d2.toString());
+        }
+        // Migrate custom effects
+        QDomNodeList effectsElement = m_doc.elementsByTagName("customeffects");
+        if (!effectsElement.isEmpty()) {
+            QDomElement effects = effectsElement.at(0).toElement();
+            QDomDocument d2;
+            d2.importNode(effects, true);
+            EffectsList::setProperty(playlist, "kdenlive:customeffects", d2.toString());
+        }
+        EffectsList::setProperty(playlist, "kdenlive:docproperties.version", QString::number(currentVersion));
+        if (!infoXml.isNull()) EffectsList::setProperty(playlist, "kdenlive:docproperties.projectfolder", infoXml.attribute("projectfolder"));
+    }
     m_modified = true;
     return true;
 }
@@ -1061,8 +1347,9 @@ QString DocumentValidator::colorToString(const QColor& c)
 
 bool DocumentValidator::isProject() const
 {
-    QDomNode infoXmlNode = m_doc.elementsByTagName("kdenlivedoc").at(0);
-    return !infoXmlNode.isNull();
+    return m_doc.documentElement().tagName() == "mlt";
+    /*QDomNode infoXmlNode = m_doc.elementsByTagName("kdenlivedoc").at(0);
+    return !infoXmlNode.isNull();*/
 }
 
 bool DocumentValidator::isModified() const
@@ -1070,6 +1357,7 @@ bool DocumentValidator::isModified() const
     return m_modified;
 }
 
+/*
 void DocumentValidator::updateEffects()
 {
     // WARNING: order by findDirs will determine which js file to use (in case multiple scripts for the same filter exist)
@@ -1196,4 +1484,132 @@ bool DocumentValidator::updateEffectParameters(const QDomNodeList &parameters, c
     }
     return updated;
 }
+*/
+
+bool DocumentValidator::checkMovit()
+{
+    QString playlist = m_doc.toString();
+    if (!playlist.contains("movit.")) {
+        // Project does not use Movit GLSL effects, we can load it
+        return true;
+    }
+    if (KMessageBox::questionYesNo(QApplication::activeWindow(), i18n("The project file uses some GPU effects. GPU acceleration is not currently enabled.\nDo you want to convert the project to a non-GPU version ?\nThis might result in data loss.")) != KMessageBox::Yes) {
+        return false;
+    }
+    // Try to convert Movit filters to their non GPU equivalent
+    
+    QStringList convertedFilters;
+    QStringList discardedFilters;
+    int ix = MainWindow::videoEffects.hasEffect("frei0r.colgate", "frei0r.colgate");
+    bool hasWB = ix > -1;
+    ix = MainWindow::videoEffects.hasEffect("frei0r.IIRblur", "frei0r.IIRblur");
+    bool hasBlur = ix > -1;
+    ix = MainWindow::transitions.hasTransition("frei0r.cairoblend");
+    bool hasCairo = ix > -1;
+    
+    // Parse all effects in document
+    QDomNodeList filters = m_doc.elementsByTagName("filter");
+    int max = filters.count();
+    QLocale locale;
+    for (int i = 0; i < max; ++i) {
+        QDomElement filt = filters.at(i).toElement();
+        QString filterId = filt.attribute("id");
+        if (!filterId.startsWith("movit.")) {
+            continue;
+        }
+        if (filterId == "movit.white_balance" && hasWB) {
+            // Convert to frei0r.colgate
+            filt.setAttribute("id", "frei0r.colgate");
+            EffectsList::setProperty(filt, "kdenlive_id", "frei0r.colgate");
+            EffectsList::setProperty(filt, "tag", "frei0r.colgate");
+            EffectsList::setProperty(filt, "mlt_service", "frei0r.colgate");
+            EffectsList::renameProperty(filt, "neutral_color", "Neutral Color");
+            QString value = EffectsList::property(filt, "color_temperature");
+            value = factorizeGeomValue(value, 15000.0);
+            EffectsList::setProperty(filt, "color_temperature", value);
+            EffectsList::renameProperty(filt, "color_temperature", "Color Temperature");
+            convertedFilters << filterId;
+            continue;
+        }
+        if (filterId == "movit.blur" && hasBlur) {
+            // Convert to frei0r.IIRblur
+            filt.setAttribute("id", "frei0r.IIRblur");
+            EffectsList::setProperty(filt, "kdenlive_id", "frei0r.IIRblur");
+            EffectsList::setProperty(filt, "tag", "frei0r.IIRblur");
+            EffectsList::setProperty(filt, "mlt_service", "frei0r.IIRblur");
+            EffectsList::renameProperty(filt, "radius", "Amount");
+            QString value = EffectsList::property(filt, "Amount");
+            value = factorizeGeomValue(value, 14.0);
+            EffectsList::setProperty(filt, "Amount", value);
+            convertedFilters << filterId;
+            continue;
+        }
+        if (filterId == "movit.mirror") {
+            // Convert to MLT's mirror
+            filt.setAttribute("id", "mirror");
+            EffectsList::setProperty(filt, "kdenlive_id", "mirror");
+            EffectsList::setProperty(filt, "tag", "mirror");
+            EffectsList::setProperty(filt, "mlt_service", "mirror");
+            EffectsList::setProperty(filt, "mirror", "flip");
+            convertedFilters << filterId;
+            continue;
+        }
+        if (filterId.startsWith("movit.")) {
+            //TODO: implement conversion for more filters
+            discardedFilters << filterId;
+        }
+    }
+    
+    // Parse all transitions in document
+    QDomNodeList transitions = m_doc.elementsByTagName("transition");
+    max = transitions.count();
+    for (int i = 0; i < max; ++i) {
+        QDomElement t = transitions.at(i).toElement();
+        QString transId = EffectsList::property(t, "mlt_service");
+        if (!transId.startsWith("movit.")) {
+            continue;
+        }
+        if (transId == "movit.overlay" && hasCairo) {
+            // Convert to frei0r.colgate
+            EffectsList::setProperty(t, "mlt_service", "frei0r.cairoblend");
+            convertedFilters << transId;
+            continue;
+        }
+        if (transId.startsWith("movit.")) {
+            //TODO: implement conversion for more filters
+            discardedFilters << transId;
+        }
+    }
+
+    convertedFilters.removeDuplicates();
+    discardedFilters.removeDuplicates();
+    if (discardedFilters.isEmpty()) {
+        KMessageBox::informationList(QApplication::activeWindow(), i18n("The following filters/transitions were converted to non GPU versions:"), convertedFilters);
+    }
+    else {
+        KMessageBox::informationList(QApplication::activeWindow(), i18n("The following filters/transitions were deleted from the project:"), discardedFilters);
+    }
+    m_modified = true;
+    QString scene = m_doc.toString();
+    scene.replace("movit.", "");
+    m_doc.setContent(scene);
+    return true;
+}
+
+QString DocumentValidator::factorizeGeomValue(QString value, double factor)
+{
+    QStringList vals = value.split(";");
+    QString result;
+    QLocale locale;
+    for (int i = 0; i < vals.count(); i++) {
+        QString s = vals.at(i);
+        QString key = s.section("=", 0, 0);
+        QString val = s.section("=", 1, 1);
+        double v = locale.toDouble(val) / factor;
+        result.append(key + "=" + locale.toString(v));
+        if ( i + 1 < vals.count()) result.append(";");
+    }
+    return result;
+}
+
 
