@@ -30,21 +30,25 @@
 #include <QList>
 #include <QDir>
 #include <QObject>
-
+#include <QTimer>
 #include <QUrl>
+
 #include <kautosavefile.h>
+#include <KDirWatch>
 
 #include "gentime.h"
 #include "timecode.h"
 #include "definitions.h"
 #include "timeline/guide.h"
+#include "mltcontroller/effectscontroller.h"
 
 class Render;
 class ClipManager;
-class DocClipBase;
 class MainWindow;
 class TrackInfo;
 class NotesPlugin;
+class ProjectClip;
+class ClipController;
 
 class QTextEdit;
 class QProgressDialog;
@@ -52,6 +56,10 @@ class QUndoGroup;
 class QTimer;
 class QUndoStack;
 
+namespace Mlt {
+    class Profile;
+}
+
 class KdenliveDoc: public QObject
 {
     Q_OBJECT
@@ -67,16 +75,14 @@ public:
     KAutoSaveFile *m_autosave;
     Timecode timecode() const;
     QDomDocument toXml();
-    //void setRenderer(Render *render);
     QUndoStack *commandStack();
     Render *renderer();
-    QDomDocument m_guidesXml;
-    QDomElement guidesXml() const;
     ClipManager *clipManager();
+    QString groupsXml() const;
 
     /** @brief Adds a clip to the project tree.
      * @return false if the user aborted the operation, true otherwise */
-    bool addClip(QDomElement elem, const QString &clipId, bool createClipItem = true);
+    bool addClip(QDomElement elem, const QString &clipId);
 
     /** @brief Updates information about a clip.
      * @param elem the <kdenlive_producer />
@@ -86,63 +92,38 @@ public:
      *     there yet), true otherwise
      *
      * If the clip wasn't added before, it tries to add it to the project. */
-    bool addClipInfo(QDomElement elem, QDomElement orig, const QString &clipId);
-    void slotAddClipList(const QList<QUrl> &urls, const stringMap &data = stringMap());
+    //bool addClipInfo(QDomElement elem, QDomElement orig, const QString &clipId);
     void deleteClip(const QString &clipId);
     int getFramePos(const QString &duration);
-    DocClipBase *getBaseClip(const QString &clipId);
+    /** @brief Get a bin's clip from its id. */
+    ProjectClip *getBinClip(const QString &clipId);
+    /** @brief Get a list of all clip ids that are inside a folder. */
+    QStringList getBinFolderClipIds(const QString &folderId) const;
+    ClipController *getClipController(const QString &clipId);
     void updateClip(const QString &id);
 
     /** @brief Informs Kdenlive of the audio thumbnails generation progress. */
     void setThumbsProgress(const QString &message, int progress);
     const QString &profilePath() const;
+    /** @brief Returns current project profile. */
     MltVideoProfile mltProfile() const;
+    ProfileInfo getProfileInfo() const;
     const QString description() const;
     void setUrl(const QUrl &url);
 
-    /** @brief Updates the project profile.
-     * @return true if frame rate was changed */
-    bool setProfilePath(QString path);
-    const QString getFreeClipId();
-
     /** @brief Defines whether the document needs to be saved. */
     bool isModified() const;
 
     /** @brief Returns the project folder, used to store project files. */
     QUrl projectFolder() const;
-    void syncGuides(const QList <Guide *> &guides);
     void setZoom(int horizontal, int vertical);
     QPoint zoom() const;
     double dar() const;
     double projectDuration() const;
     /** @brief Returns the project file xml. */
-    QDomDocument xmlSceneList(const QString &scene, const QStringList &expandedFolders);
+    QDomDocument xmlSceneList(const QString &scene);
     /** @brief Saves the project file xml to a file. */
-    bool saveSceneList(const QString &path, const QString &scene, const QStringList &expandedFolders);
-    int tracksCount() const;
-    TrackInfo trackInfoAt(int ix) const;
-    void insertTrack(int ix, const TrackInfo &type);
-    void deleteTrack(int ix);
-    void setTrackType(int ix, const TrackInfo &type);
-    const QList <TrackInfo> tracksList() const;
-
-    /** @brief Gets the number of audio and video tracks and returns them as a QPoint with x = video, y = audio. */
-    QPoint getTracksCount() const;
-
-    void switchTrackVideo(int ix, bool hide);
-    void switchTrackAudio(int ix, bool hide);
-    void switchTrackLock(int ix, bool lock);
-    bool isTrackLocked(int ix) const;
-
-    /** @brief Sets the duration of track @param ix to @param duration.
-     * This does not! influence the actual track but only the value in its TrackInfo. */
-    void setTrackDuration(int ix, int duration);
-
-    /** @brief Returns the duration of track @param ix.
-     *
-     * The returned duration might differ from the actual track duration!
-     * It is the one stored in the track's TrackInfo. */
-    int trackDuration(int ix);
+    bool saveSceneList(const QString &path, const QString &scene);
     void cacheImage(const QString &fileId, const QImage &img) const;
     void setProjectFolder(QUrl url);
     void setZone(int start, int end);
@@ -153,15 +134,6 @@ public:
 
     /** @brief Gets the list of renderer properties saved into the document. */
     QMap <QString, QString> getRenderProperties() const;
-    void addTrackEffect(int ix, QDomElement effect);
-    void removeTrackEffect(int ix, const QDomElement &effect);
-    void setTrackEffect(int trackIndex, int effectIndex, QDomElement effect);
-    const EffectsList getTrackEffects(int ix);
-    /** @brief Enable / disable an effect in Kdenlive's xml list. */
-    void enableTrackEffects(int trackIndex, const QList<int> &effectIndexes, bool disable);
-    QDomElement getTrackEffect(int trackIndex, int effectIndex) const;
-    /** @brief Check if a track already contains a specific effect. */
-    int hasTrackEffect(int trackIndex, const QString &tag, const QString &id) const;
     /** @brief Get a list of folder id's that were opened on last save. */
     QStringList getExpandedFolders();
     /** @brief Read the display ratio from an xml project file. */
@@ -172,11 +144,26 @@ public:
     const QMap <QString, QString> metadata() const;
     /** @brief Set the document metadata (author, copyright, ...) */
     void setMetadata(const QMap <QString, QString>& meta);
-    
+    /** @brief Get frame size of the renderer (profile)*/
+    const QSize getRenderSize() const;
+    /** @brief Add url to the file watcher so that we monitor changes */
+    void watchFile(const QUrl &url);
+    /** @brief Get all document properties that need to be saved */
+    const QMap <QString, QString> documentProperties();
+    bool useProxy() const;
+    QString documentNotes() const;
+    /** @brief Saves effects embedded in project file. */
+    void saveCustomEffects(const QDomNodeList &customeffects);
+    void resetProfile();
+
 private:
     QUrl m_url;
     QDomDocument m_document;
-    double m_fps;
+    KDirWatch m_fileWatcher;
+    /** Timer used to reload clips when they have been externally modified */
+    QTimer m_modifiedTimer;
+    /** List of the clip IDs that need to be reloaded after being externally modified */
+    QMap <QString, QTime> m_modifiedClips;
     int m_width;
     int m_height;
     Timecode m_timecode;
@@ -185,7 +172,6 @@ private:
     QUndoStack *m_commandStack;
     ClipManager *m_clipManager;
     MltVideoProfile m_profile;
-    QTimer *m_autoSaveTimer;
     QString m_searchFolder;
 
     /** @brief Tells whether the current document has been changed after being saved. */
@@ -196,7 +182,6 @@ private:
     QMap <QString, QString> m_documentProperties;
     QMap <QString, QString> m_documentMetadata;
 
-    QList <TrackInfo> m_tracksList;
     void setNewClipResource(const QString &id, const QString &path);
     QString searchFileRecursively(const QDir &dir, const QString &matchSize, const QString &matchHash) const;
     void moveProjectData(const QUrl &url);
@@ -206,32 +191,22 @@ private:
      * @param infoproducers
      * @return
      */
-    bool checkDocumentClips(QDomNodeList infoproducers);
+    bool checkDocumentClips();
 
     /** @brief Creates a new project. */
     QDomDocument createEmptyDocument(int videotracks, int audiotracks);
     QDomDocument createEmptyDocument(const QList<TrackInfo> &tracks);
-    /** @brief Saves effects embedded in project file.
-    *   @return True if effects were imported.  */
-    bool saveCustomEffects(const QDomNodeList &customeffects);
 
     /** @brief Updates the project folder location entry in the kdenlive file dialogs to point to the current project folder. */
     void updateProjectFolderPlacesEntry();
     /** @brief Only keep some backup files, delete some */
     void cleanupBackupFiles();
+    /** @brief Load document properties from the xml file */
+    void loadDocumentProperties();
+    /** @brief update document properties to reflect a change in the current profile */
+    void updateProjectProfile();
 
 public slots:
-    void slotCreateXmlClip(const QString &name, const QDomElement &xml, const QString &group, const QString &groupId);
-    void slotCreateColorClip(const QString &name, const QString &color, const QString &duration, const QString &group, const QString &groupId);
-    void slotCreateSlideshowClipFile(const QMap<QString, QString> &properties, const QString &group, const QString &groupId);
-    /**
-     * @brief Create a title clip.
-     *  Instansiates TitleWidget objects
-     * @param group
-     * @param groupId
-     * @param templatePath
-     */
-    void slotCreateTextClip(QString group, const QString &groupId, const QString &templatePath = QString());
     void slotCreateTextTemplateClip(const QString &group, const QString &groupId, QUrl path);
 
     /** @brief Sets the document as modified or up to date.
@@ -239,18 +214,20 @@ public slots:
      * Emits docModified conected to MainWindow::slotUpdateDocumentState \n
      * @param mod (optional) true if the document has to be saved */
     void setModified(bool mod = true);
-    void checkProjectClips(bool displayRatioChanged = false, bool fpsChanged = false);
-    void slotAddClipFile(const QUrl &url, const stringMap &data);
-
-private slots:
+    void slotProxyCurrentItem(bool doProxy);
     /** @brief Saves the current project at the autosave location.
      * @description The autosave files are in ~/.kde/data/stalefiles/kdenlive/ */
     void slotAutoSave();
 
+private slots:
+    void slotClipModified(const QString &path);
+    void slotClipMissing(const QString &path);
+    void slotProcessModifiedClips();
+    void slotModified();
+    void slotSetDocumentNotes(const QString &notes);
+
 signals:
     void resetProjectList();
-    void addProjectClip(DocClipBase *, bool getInfo = true);
-    void signalDeleteProjectClip(const QString &);
     void updateClipDisplay(const QString&);
     void progressInfo(const QString &, int);
 
@@ -262,6 +239,10 @@ signals:
     void guidesUpdated();
     /** @brief When creating a backup file, also save a thumbnail of current timeline */
     void saveTimelinePreview(const QString &path);
+    /** @brief Trigger the autosave timer start */
+    void startAutoSave();
+    /** @brief Current doc created effects, reload list */
+    void reloadEffects();
 };
 
 #endif
