@@ -26,67 +26,54 @@
 #include "renderer.h"
 #include "definitions.h"
 #include "timecodedisplay.h"
-#ifdef USE_OPENGL
-#include "monitor/videoglwidget.h"
-#endif
+#include "monitor/sharedframe.h"
+#include "effectslist/effectslist.h"
 
 #include <QLabel>
 #include <QDomElement>
 #include <QToolBar>
-
+#include <QWindow>
 #include <QIcon>
+#include <QProcess>
 
 class SmallRuler;
-class DocClipBase;
+class ClipController;
 class AbstractClipItem;
 class Transition;
 class ClipItem;
-class MonitorEditWidget;
 class Monitor;
 class MonitorManager;
 class QSlider;
-class TwostateAction;
-
-
-class Overlay : public QLabel
-{
-    Q_OBJECT
-public:
-    explicit Overlay(QWidget* parent = 0);
-    void setOverlayText(const QString &, bool isZone = true);
-
-protected:
-    void mouseDoubleClickEvent ( QMouseEvent * event );
-    void mousePressEvent ( QMouseEvent * event );
-    void mouseReleaseEvent ( QMouseEvent * event );
-    
-signals:
-    void editMarker();
-};
+class KDualAction;
+class KSelectAction;
+class KMessageWidget;
+class QQuickItem;
+class QScrollBar;
+class RecManager;
 
 class Monitor : public AbstractMonitor
 {
     Q_OBJECT
 
 public:
-    Monitor(Kdenlive::MonitorId id, MonitorManager *manager, QString profile = QString(), QWidget *parent = 0);
+    Monitor(Kdenlive::MonitorId id, MonitorManager *manager, QWidget *parent = 0);
     ~Monitor();
     Render *render;
     AbstractRender *abstractRender();
-    void resetProfile(const QString &profile);
+    void resetProfile(MltVideoProfile profile);
     void setCustomProfile(const QString &profile, const Timecode &tc);
-    void resetSize();
     void pause();
-    void setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu = NULL, QAction *loopClip = NULL, QWidget* parent = NULL);
+    void setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMenu *markerMenu = NULL, QAction *loopClip = NULL);
     const QString sceneList();
-    DocClipBase *activeClip();
+    const QString activeClipId();
     GenTime position();
+    /** @brief Check current position to show relevant infos in qml view (markers, zone in/out, etc). */
     void checkOverlay();
     void updateTimecodeFormat();
-    void updateMarkers(DocClipBase *source);
+    void updateMarkers();
+    /** @brief Controller for the clip currently displayed (only valid for clip monitor). */
+    ClipController *currentController() const;
     void setMarkers(const QList <CommentedTime> &markers);
-    MonitorEditWidget *getEffectEdit();
-    QWidget *container();
     void reloadProducer(const QString &id);
     QFrame *m_volumePopup;
     /** @brief Reimplemented from QWidget, updates the palette colors. */
@@ -97,9 +84,27 @@ public:
     double fps() const;
     /** @brief Get url for the clip's thumbnail */
     QString getMarkerThumb(GenTime pos);
-
+    /** @brief Get current project's folder */
+    const QString projectFolder() const;
+    /** @brief Get the project's profile info*/
+    ProfileInfo profileInfo() const;
+    /** @brief Get the project's Mlt profile */
+    Mlt::Profile *profile();
     int getZoneStart();
     int getZoneEnd();
+    void setUpEffectGeometry(QRect r, QVariantList list = QVariantList());
+    QRect effectRect() const;
+    void setEffectKeyframe(bool enable);
+    void sendFrameForAnalysis(bool analyse);
+    void switchMonitorInfo(bool show);
+    void switchDropFrames(bool drop);
+    void updateMonitorGamma();
+    void mute(bool, bool updateIconOnly = false);
+    bool startCapture(const QString &params, const QString &path, Mlt::Producer *p);
+    bool stopCapture();
+    void reparent();
+    /** @brief Returns the action displaying record toolbar */
+    QAction *recAction();
 
 protected:
     void mousePressEvent(QMouseEvent * event);
@@ -117,68 +122,95 @@ protected:
     virtual QStringList mimeTypes() const;
 
 private:
-    DocClipBase *m_currentClip;
+    ClipController *m_controller;
+    /** @brief The QQuickView that handles our monitor display (video and qml overlay) **/
+    GLWidget *m_glMonitor;
+    /** @brief Container for our QQuickView monitor display (QQuickView needs to be embeded) **/
+    QWidget *m_glWidget;
+    /** @brief Scrollbar for our monitor view, used when zooming the monitor **/
+    QScrollBar *m_verticalScroll;
+    /** @brief Scrollbar for our monitor view, used when zooming the monitor **/
+    QScrollBar *m_horizontalScroll;
+    /** @brief The ruler widget displaying cursor position **/
     SmallRuler *m_ruler;
-    Overlay *m_overlay;
+    /** @brief Widget holding the window for the QQuickView **/
+    QWidget *m_videoWidget;
+
+    Mlt::Filter *m_splitEffect;
+    Mlt::Producer *m_splitProducer;
     int m_length;
     bool m_dragStarted;
+    //TODO: Move capture stuff in own class
+    RecManager *m_recManager;
     QIcon m_playIcon;
     QIcon m_pauseIcon;
+    /** @brief The widget showing current time position **/
     TimecodeDisplay *m_timePos;
-    TwostateAction *m_playAction;
+    KDualAction *m_playAction;
+    KSelectAction *m_forceSize;
     /** Has to be available so we can enable and disable it. */
     QAction *m_loopClipAction;
+    QAction *m_effectCompare;
     QMenu *m_contextMenu;
     QMenu *m_configMenu;
     QMenu *m_playMenu;
     QMenu *m_markerMenu;
     QPoint m_DragStartPosition;
-    MonitorEditWidget *m_effectWidget;
     /** Selected clip/transition in timeline. Used for looping it. */
     AbstractClipItem *m_selectedClip;
     /** true if selected clip is transition, false = selected clip is clip.
      *  Necessary because sometimes we get two signals, e.g. we get a clip and we get selected transition = NULL. */
     bool m_loopClipTransition;
-
-#ifdef USE_OPENGL
-    VideoGLWidget *m_glWidget;
-    bool createOpenGlWidget(QWidget *parent, const QString &profile);
-#endif
-
     GenTime getSnapForPos(bool previous);
-    Qt::WindowFlags m_baseFlags;
     QToolBar *m_toolbar;
     QWidget *m_volumeWidget;
     QSlider *m_audioSlider;
     QAction *m_editMarker;
+    KMessageWidget *m_infoMessage;
+    int m_forceSizeFactor;
+    /** @brief The base item of the qml view in monitor, used to set properties on the view that affect display **/
+    QQuickItem *m_rootItem;
+    void adjustScrollBars(float horizontal, float vertical);
+    void loadMasterQml();
 
 private slots:
     void seekCursor(int pos);
     void rendererStopped(int pos);
     void slotExtractCurrentFrame();
     void slotSetThumbFrame();
-    void slotSetSizeOneToOne();
-    void slotSetSizeOneToTwo();
     void slotSaveZone();
     void slotSeek();
     void setClipZone(const QPoint &pos);
-    void slotSwitchMonitorInfo(bool show);
-    void slotSwitchDropFrames(bool show);
     void slotGoToMarker(QAction *action);
     void slotSetVolume(int volume);
     void slotShowVolume();
     void slotEditMarker();
     void slotExtractCurrentZone();
+    void onFrameDisplayed(const SharedFrame& frame);
+    void slotStartDrag();
+    void setZoom();
+    void slotEnableEffectScene(bool enable);
+    /** @brief split screen to compare clip with and without effect */
+    void slotSwitchCompare(bool enable);
+    void slotAdjustEffectCompare();
+    void slotShowMenu(const QPoint pos);
+    void slotForceSize(QAction *a);
+    void slotSeekToKeyFrame();
+    /** @brief Display a non blocking error message to user **/
+    void warningMessage(const QString &text);
 
 public slots:
-    void slotOpenFile(const QString &);
-    void slotSetClipProducer(DocClipBase *clip, QPoint zone = QPoint(), bool forceUpdate = false, int position = -1);
+    void slotOpenDvdFile(const QString &);
+    //void slotSetClipProducer(DocClipBase *clip, QPoint zone = QPoint(), bool forceUpdate = false, int position = -1);
     void updateClipProducer(Mlt::Producer *prod);
+    void updateClipProducer(const QString &playlist);
+    void slotOpenClip(ClipController *controller, int in = -1, int out = -1);
     void refreshMonitor(bool visible);
     void refreshMonitor();
     void slotSeek(int pos);
     void stop();
     void start();
+    void switchPlay(bool play);
     void slotPlay();
     void slotPlayZone();
     void slotLoopZone();
@@ -198,11 +230,11 @@ public slots:
     void slotZoneMoved(int start, int end);
     void slotSeekToNextSnap();
     void slotSeekToPreviousSnap();
-    void adjustRulerSize(int length);
+    void adjustRulerSize(int length, int offset = 0);
     void setTimePos(const QString &pos);
     QStringList getZoneInfo() const;
     /** @brief Display the on monitor effect scene (to adjust geometry over monitor). */
-    void slotShowEffectScene(bool show = true, bool manuallyTriggered = false);
+    void slotShowEffectScene(bool show = true);
     bool effectSceneDisplayed();
 
     /** @brief Sets m_selectedClip to @param item. Used for looping it. */
@@ -210,20 +242,28 @@ public slots:
     void slotSetSelectedClip(ClipItem *item);
     void slotSetSelectedClip(Transition *item);
     void slotMouseSeek(int eventDelta, bool fast);
-    void slotSwitchFullScreen();
+    void slotSwitchFullScreen(bool minimizeOnly = false);
+    /** @brief Display or hide the record toolbar */
+    void slotSwitchRec(bool enable);
 
 signals:
     void renderPosition(int);
     void durationChanged(int);
-    void refreshClipThumbnail(const QString &, bool);
-    void adjustMonitorSize();
+    void refreshClipThumbnail(const QString &);
     void zoneUpdated(const QPoint&);
-    void saveZone(Render *, const QPoint&, DocClipBase *);
+    //void saveZone(Render *, const QPoint&, DocClipBase *);
     /** @brief  Editing transitions / effects over the monitor requires the renderer to send frames as QImage.
      *      This causes a major slowdown, so we only enable it if required */
     void requestFrameForAnalysis(bool);
     /** @brief Request a zone extraction (ffmpeg transcoding). */
-    void extractZone(const QString &id, const QPoint &zone);
+    void extractZone(const QString &id);
+    void effectChanged(const QRect);
+    void addKeyframe();
+    void seekToKeyframe(int);
+    void addClipToProject(QUrl);
+    void showConfigDialog(int,int);
+    /** @brief Request display of current bin clip. */
+    void refreshCurrentClip();
 };
 
 #endif
