@@ -27,6 +27,12 @@
 #include "timecode.h"
 
 class KdenliveDoc;
+class BinController;
+class KDualAction;
+
+namespace Mlt {
+    class Profile;
+}
 
 class MonitorManager : public QObject
 {
@@ -38,8 +44,9 @@ public:
     void appendMonitor(AbstractMonitor *monitor);
     void removeMonitor(AbstractMonitor *monitor);
     Timecode timecode() const;
-    void resetProfiles(const Timecode &tc);
+    void resetProfiles(MltVideoProfile profile, const Timecode &tc);
     void stopActiveMonitor();
+    void pauseActiveMonitor();
     AbstractRender *activeRenderer();
     /** Searches for a monitor with the given name.
 	@return NULL, if no monitor could be found, or the monitor otherwise.
@@ -53,6 +60,8 @@ public:
     void setDocument(KdenliveDoc *doc);
     /** @brief Change an MLT consumer property for both monitors. */
     void setConsumerProperty(const QString &name, const QString &value);
+    BinController *binController();
+    Mlt::Profile *profile();
 
     Monitor *clipMonitor();
     Monitor *projectMonitor();
@@ -75,7 +84,6 @@ public slots:
     void slotForwardOneSecond();
     void slotStart();
     void slotEnd();
-    void slotResetProfiles();
     void slotZoneStart();
     void slotZoneEnd();
     void slotSetInPoint();
@@ -97,17 +105,20 @@ private slots:
     void slotSetDeinterlacer(int ix);
     /** @brief Set MLT's consumer interpolation method */
     void slotSetInterpolation(int ix);
+    /** @brief Switch muting on/off */
+    void slotMuteCurrentMonitor(bool active);
 
 private:
     /** @brief Sets up all the actions and attaches them to the collection of MainWindow. */
     void setupActions();
-
     KdenliveDoc *m_document;
     Monitor *m_clipMonitor;
     Monitor *m_projectMonitor;
     Timecode m_timecode;
     AbstractMonitor *m_activeMonitor;
     QList <AbstractMonitor *>m_monitorsList;
+    KDualAction *m_muteAction;
+    void updateAudioIcons();
 
 signals:
     /** @brief When the monitor changed, update the visible color scopes */
