@@ -94,8 +94,8 @@ ClipTranscode::ClipTranscode(const QStringList &urls, const QString &params, con
     connect(button_start, SIGNAL(clicked()), this, SLOT(slotStartTransCode()));
 
     m_transcodeProcess.setProcessChannelMode(QProcess::MergedChannels);
-    connect(&m_transcodeProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(slotShowTranscodeInfo()));
-    connect(&m_transcodeProcess, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotTranscodeFinished(int,QProcess::ExitStatus)));
+    connect(&m_transcodeProcess, &QProcess::readyReadStandardOutput, this, &ClipTranscode::slotShowTranscodeInfo);
+    connect(&m_transcodeProcess, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &ClipTranscode::slotTranscodeFinished);
     
     ffmpeg_params->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 5);
 
@@ -151,19 +151,21 @@ void ClipTranscode::slotStartTransCode()
     }
 
     bool replaceVfParams = false;
-    foreach(QString s, params.split(' ')) {
+    QStringList splitted = params.split(' ');
+    foreach(QString s, splitted) {
         if (replaceVfParams) {
-            s= m_postParams.at(1);
+            parameters << m_postParams.at(1);
             replaceVfParams = false;
         } else if (s.startsWith(QLatin1String("%1"))) {
             parameters << s.replace(0, 2, destination);
-        } else if (s == "-vf") {
+        } else if (!m_postParams.isEmpty() && s == "-vf") {
             replaceVfParams = true;
+            parameters << s;
+        } else {
+            parameters << s;
         }
     }
-    
     buttonBox->button(QDialogButtonBox::Abort)->setText(i18n("Abort"));
-
     m_destination = destination + extension;
     m_transcodeProcess.start(KdenliveSettings::ffmpegpath(), parameters);
     source_url->setEnabled(false);
