@@ -19,6 +19,7 @@
 
 #include "slideshowclip.h"
 #include "kdenlivesettings.h"
+#include "bin/projectclip.h"
 
 #include <KFileItem>
 #include <klocalizedstring.h>
@@ -30,7 +31,7 @@
 #include <QStandardPaths>
 
 
-SlideshowClip::SlideshowClip(const Timecode &tc, QWidget * parent) :
+SlideshowClip::SlideshowClip(const Timecode &tc, QString clipFolder, ProjectClip *clip, QWidget * parent) :
     QDialog(parent),
     m_count(0),
     m_timecode(tc),
@@ -39,7 +40,11 @@ SlideshowClip::SlideshowClip(const Timecode &tc, QWidget * parent) :
     setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
     setWindowTitle(i18n("Add Slideshow Clip"));
     m_view.setupUi(this);
-    m_view.clip_name->setText(i18n("Slideshow Clip"));
+    if (clip) {
+        m_view.clip_name->setText(clip->name());
+        m_view.groupBox->setHidden(true);
+    }
+    else m_view.clip_name->setText(i18n("Slideshow Clip"));
     m_view.folder_url->setMode(KFile::Directory);
     m_view.folder_url->setUrl(QUrl::fromLocalFile(KRecentDirs::dir(":KdenliveSlideShowFolder")));
     m_view.icon_list->setIconSize(QSize(50, 50));
@@ -76,6 +81,11 @@ SlideshowClip::SlideshowClip(const Timecode &tc, QWidget * parent) :
     m_view.luma_duration->setInputMask(m_timecode.mask());
     m_view.luma_duration->setText(m_timecode.getTimecodeFromFrames(int(ceil(m_timecode.fps()))));
 
+    if (clipFolder.isEmpty()) {
+        clipFolder = QDir::homePath();
+    }
+    m_view.folder_url->setUrl(QUrl::fromLocalFile(clipFolder));
+
     m_view.clip_duration_format->addItem(i18n("hh:mm:ss:ff"));
     m_view.clip_duration_format->addItem(i18n("Frames"));
     connect(m_view.clip_duration_format, SIGNAL(activated(int)), this, SLOT(slotUpdateDurationFormat(int)));
@@ -110,6 +120,29 @@ SlideshowClip::SlideshowClip(const Timecode &tc, QWidget * parent) :
         QString filePath = lumafolder.absoluteFilePath(fname);
         m_view.luma_file->addItem(QIcon::fromTheme(filePath), fname, filePath);
     }
+    
+    if (clip) {
+        m_view.slide_loop->setChecked(clip->getProducerIntProperty("loop"));
+        m_view.slide_crop->setChecked(clip->getProducerIntProperty("crop"));
+        m_view.slide_fade->setChecked(clip->getProducerIntProperty("fade"));
+        m_view.luma_softness->setValue(clip->getProducerIntProperty("softness"));
+        QString anim = clip->getProducerProperty("animation");
+        if (!anim.isEmpty())
+            m_view.animation->setCurrentItem(anim);
+        else
+            m_view.animation->setCurrentIndex(0);
+        int ttl = clip->getProducerIntProperty("ttl");
+        m_view.clip_duration->setText(tc.getTimecodeFromFrames(ttl));
+        m_view.clip_duration_frames->setValue(ttl);
+        m_view.luma_duration->setText(tc.getTimecodeFromFrames(clip->getProducerIntProperty("luma_duration")));
+        QString lumaFile = clip->getProducerProperty("luma_file");
+        if (!lumaFile.isEmpty()) {
+            m_view.luma_fade->setChecked(true);
+            m_view.luma_file->setCurrentIndex(m_view.luma_file->findData(lumaFile));
+        } else m_view.luma_file->setEnabled(false);
+        slotEnableLuma(m_view.slide_fade->checkState());
+        slotEnableLumaFile(m_view.luma_fade->checkState());
+    }
 
     //adjustSize();
 }
@@ -141,7 +174,7 @@ void SlideshowClip::slotEnableThumbs(int state)
     } else {
         KdenliveSettings::setShowslideshowthumbs(false);
         if (m_thumbJob) {
-            disconnect(m_thumbJob, SIGNAL(gotPreview(KFileItem,QPixmap)), this, SLOT(slotSetPixmap(KFileItem,QPixmap)));
+            disconnect(m_thumbJob, &KIO::PreviewJob::gotPreview, this, &SlideshowClip::slotSetPixmap);
             m_thumbJob->kill();
             m_thumbJob = NULL;
         }
@@ -236,7 +269,7 @@ void SlideshowClip::slotGenerateThumbs()
     m_thumbJob = new KIO::PreviewJob(fileList, QSize(50, 50));
     m_thumbJob->setScaleType(KIO::PreviewJob::Scaled);
     m_thumbJob->setAutoDelete(false);
-    connect(m_thumbJob, SIGNAL(gotPreview(KFileItem,QPixmap)), this, SLOT(slotSetPixmap(KFileItem,QPixmap)));
+    connect(m_thumbJob, &KIO::PreviewJob::gotPreview, this, &SlideshowClip::slotSetPixmap);
     m_thumbJob->start();
 }
 
@@ -285,7 +318,10 @@ QString SlideshowClip::selectedPath(const QUrl &url, bool isMime, QString extens
 {
     QString folder;
     if (isMime) {
-        folder = url.path() + QDir::separator();
+        folder = url.path();
+        if (!folder.endsWith(QDir::separator())) {
+            folder.append(QDir::separator());
+        }
 	// Check how many files we have
         QDir dir(folder);
 	QStringList filters;
@@ -443,5 +479,3 @@ QString SlideshowClip::animationToGeometry(const QString &animation, int &ttl)
 
 
 
-
-
