@@ -43,27 +43,18 @@ MeltJob::MeltJob(ClipType cType, const QString id, const QMap <QString, QString>
     m_profile(NULL),
     m_filter(NULL),
     m_showFrameEvent(NULL),
-    m_length(0),
     m_producerParams(producerParams),
     m_filterParams(filterParams),
     m_consumerParams(consumerParams),
+    m_length(0),
     m_extra(extraParams)
 {
     m_jobStatus = JobWaiting;
-    description = i18n("Process clip");
+    description = i18n("Processing clip");
     QString consum = m_consumerParams.value("consumer");
     if (consum.contains(QLatin1Char(':')))
         m_dest = consum.section(QLatin1Char(':'), 1);
-}
-
-void MeltJob::setProducer(Mlt::Producer *producer, const QUrl &url)
-{
-    Q_UNUSED(producer)
-
-    //FIX stabilize in proxy clips?
-    //m_url = QString::fromUtf8(producer->get("resource"));
-    //if (m_url == QLatin1String("<playlist>") || m_url == QLatin1String("<tractor>") || m_url == QLatin1String("<producer>"))
-        m_url = url.path();
+    m_url = producerParams.value("producer");
 }
 
 void MeltJob::startJob()
@@ -104,29 +95,44 @@ void MeltJob::startJob()
 	m_profile = new Mlt::Profile(KdenliveSettings::current_profile().toUtf8().constData());
     }
     if (m_extra.contains(QLatin1String("resize_profile"))) {
-    m_profile->set_height(m_extra.value(QLatin1String("resize_profile")).toInt());
+        m_profile->set_height(m_extra.value(QLatin1String("resize_profile")).toInt());
 	m_profile->set_width(m_profile->height() * m_profile->sar());
     }
+    double fps = m_profile->fps();
     if (out == -1) {
 	m_producer = new Mlt::Producer(*m_profile,  m_url.toUtf8().constData());
-	if (m_producer) m_length = m_producer->get_length();
+        if (m_producer && m_extra.contains(QLatin1String("producer_profile"))) {
+            m_profile->from_producer(*m_producer);
+            m_profile->set_explicit(true);
+        }
+        if (m_profile->fps() != fps) {
+            // Reload producer
+            delete m_producer;
+            m_producer = new Mlt::Producer(*m_profile,  m_url.toUtf8().constData());
+        }
     }
     else {
 	Mlt::Producer *tmp = new Mlt::Producer(*m_profile,  m_url.toUtf8().constData());
+        if (tmp && m_extra.contains(QLatin1String("producer_profile"))) {
+            m_profile->from_producer(*tmp);
+            m_profile->set_explicit(true);
+        }
+        if (m_profile->fps() != fps) {
+            // Reload producer
+            delete tmp;
+            tmp = new Mlt::Producer(*m_profile,  m_url.toUtf8().constData());
+        }
         if (tmp) m_producer = tmp->cut(in, out);
 	delete tmp;
-	if (m_producer) m_length = m_producer->get_playtime();
     }
+
     if (!m_producer || !m_producer->is_valid()) {
 	// Clip was removed or something went wrong, Notify user?
 	//m_errorMessage.append(i18n("Invalid clip"));
         setStatus(JobCrashed);
 	return;
     }
-    if (m_extra.contains(QLatin1String("producer_profile"))) {
-	m_profile->from_producer(*m_producer);
-	m_profile->set_explicit(true);
-    }
+    m_length = m_producer->get_length();
 
     // Process producer params
     QMapIterator<QString, QString> i(m_producerParams);
@@ -154,7 +160,6 @@ void MeltJob::startJob()
     }
 
     m_consumer->set("real_time", -KdenliveSettings::mltthreads() );
-
     // Process consumer params
     QMapIterator<QString, QString> j(m_consumerParams);
     ignoredProps.clear();
@@ -168,33 +173,34 @@ void MeltJob::startJob()
     }
 
     // Build filter
-    m_filter = new Mlt::Filter(*m_profile, filterName.toUtf8().data());
-    if (!m_filter || !m_filter->is_valid()) {
-	m_errorMessage = i18n("Filter %1 crashed", filterName);
-        setStatus(JobCrashed);
-	return;
-    }
+    if (!filterName.isEmpty()) {
+        m_filter = new Mlt::Filter(*m_profile, filterName.toUtf8().data());
+        if (!m_filter || !m_filter->is_valid()) {
+            m_errorMessage = i18n("Filter %1 crashed", filterName);
+            setStatus(JobCrashed);
+            return;
+        }
 
-    // Process filter params
-    QMapIterator<QString, QString> k(m_filterParams);
-    ignoredProps.clear();
-    ignoredProps << "filter";
-    while (k.hasNext()) {
-	k.next();
-	QString key = k.key();
-	if (!ignoredProps.contains(key)) {
-	    m_filter->set(k.key().toUtf8().constData(), k.value().toUtf8().constData());
-	}
+        // Process filter params
+        QMapIterator<QString, QString> k(m_filterParams);
+        ignoredProps.clear();
+        ignoredProps << "filter";
+        while (k.hasNext()) {
+            k.next();
+            QString key = k.key();
+            if (!ignoredProps.contains(key)) {
+                m_filter->set(k.key().toUtf8().constData(), k.value().toUtf8().constData());
+            }
+        }
     }
-
-    Mlt::Tractor tractor;
+    Mlt::Tractor tractor(*m_profile);
     Mlt::Playlist playlist;
     playlist.append(*m_producer);
     tractor.set_track(playlist, 0);
     m_consumer->connect(tractor);
     m_producer->set_speed(0);
     m_producer->seek(0);
-    m_producer->attach(*m_filter);
+    if (m_filter) m_producer->attach(*m_filter);
     m_showFrameEvent = m_consumer->listen("consumer-frame-show", this, (mlt_listener) consumer_frame_render);
     m_producer->set_speed(1);
     m_consumer->run();
@@ -207,7 +213,7 @@ void MeltJob::startJob()
     if (!jobResults.isEmpty() && m_jobStatus != JobAborted) {
 	emit gotFilterJobResults(m_clipId, startPos, track, jobResults, m_extra);
     }
-    if (m_jobStatus == JobAborted || m_jobStatus == JobWorking) m_jobStatus = JobDone;
+    if (m_jobStatus == JobWorking) m_jobStatus = JobDone;
 }
 
 
@@ -249,7 +255,7 @@ const QString MeltJob::statusMessage()
 
 void MeltJob::emitFrameNumber(int pos)
 {
-    if (m_length > 0) {
+    if (m_length > 0 && m_jobStatus != JobAborted) {
         emit jobProgress(m_clipId, (int) (100 * pos / m_length), jobType);
     }
 }
