@@ -10,11 +10,13 @@ the Free Software Foundation, either version 3 of the License, or
 
 #include "projectmanager.h"
 #include "core.h"
+#include "bin/bin.h"
+#include "mltcontroller/bincontroller.h"
 #include "mainwindow.h"
 #include "kdenlivesettings.h"
 #include "monitor/monitormanager.h"
 #include "doc/kdenlivedoc.h"
-#include "timeline/trackview.h"
+#include "timeline/timeline.h"
 #include "project/dialogs/projectsettings.h"
 #include "projectlist.h"
 #include "timeline/customtrackview.h"
@@ -54,33 +56,49 @@ ProjectManager::ProjectManager(QObject* parent) :
     connect(backupAction, SIGNAL(triggered(bool)), SLOT(slotOpenBackup()));
 
     m_notesPlugin = new NotesPlugin(this);
+
+    m_autoSaveTimer.setSingleShot(true);
+    connect(&m_autoSaveTimer, SIGNAL(timeout()), this, SLOT(slotAutoSave()));
 }
 
 ProjectManager::~ProjectManager()
 {
+    delete m_notesPlugin;
+
+    if (m_trackView) {
+        delete m_trackView;
+    }
+    if (m_project) {
+	delete m_project;
+    }
 }
 
-void ProjectManager::init(const QUrl& projectUrl, const QString& clipList)
+void ProjectManager::slotLoadOnOpen()
 {
-    if (projectUrl.isValid()) {
-        // delay loading so that the window shows up
-        m_startUrl = projectUrl;
-        QTimer::singleShot(500, this, SLOT(openFile()));
-    } else if (KdenliveSettings::openlastproject()) {
-        QTimer::singleShot(500, this, SLOT(openLastFile()));
-    } else {
-        newFile(false);
+    if (m_startUrl.isValid()) {
+        openFile();
     }
+    else if (KdenliveSettings::openlastproject()) {
+        openLastFile();
+    }
+    else newFile(false);
 
-    if (!clipList.isEmpty() && m_project) {
-        QStringList list = clipList.split(',');
+    if (!m_loadClipsOnOpen.isEmpty() && m_project) {
+        QStringList list = m_loadClipsOnOpen.split(',');
         QList <QUrl> urls;
         foreach(const QString &path, list) {
             //qDebug() << QDir::current().absoluteFilePath(path);
             urls << QUrl::fromLocalFile(QDir::current().absoluteFilePath(path));
         }
-        pCore->window()->m_projectList->slotAddClip(urls);
+        pCore->bin()->droppedUrls(urls);
     }
+    m_loadClipsOnOpen.clear();
+}
+
+void ProjectManager::init(const QUrl& projectUrl, const QString& clipList)
+{
+    m_startUrl = projectUrl;
+    m_loadClipsOnOpen = clipList;
 }
 
 void ProjectManager::newFile(bool showProjectSettings, bool force)
@@ -133,14 +151,15 @@ void ProjectManager::newFile(bool showProjectSettings, bool force)
         delete w;
     }
     pCore->window()->m_timelineArea->setEnabled(true);
-    pCore->window()->m_projectList->setEnabled(true);
     bool openBackup;
+    m_notesPlugin->clear();
     KdenliveDoc *doc = new KdenliveDoc(QUrl(), projectFolder, pCore->window()->m_commandStack, profileName, documentProperties, documentMetadata, projectTracks, pCore->monitorManager()->projectMonitor()->render, m_notesPlugin, &openBackup, pCore->window());
+    pCore->monitorManager()->resetProfiles(doc->mltProfile(), doc->timecode());
     doc->m_autosave = new KAutoSaveFile(startFile, doc);
     bool ok;
-    m_trackView = new TrackView(doc, pCore->window()->m_tracksActionCollection->actions(), &ok, pCore->window());
+    pCore->bin()->setDocument(doc);
+    m_trackView = new Timeline(doc, pCore->window()->m_tracksActionCollection->actions(), &ok, pCore->window());
     pCore->window()->m_timelineArea->addTab(m_trackView, QIcon::fromTheme("kdenlive"), doc->description());
-
     m_project = doc;
     if (!ok) {
         // MLT is broken
@@ -154,9 +173,10 @@ void ProjectManager::newFile(bool showProjectSettings, bool force)
     pCore->window()->connectDocument();
     emit docOpened(m_project);
     pCore->monitorManager()->activateMonitor(Kdenlive::ClipMonitor);
+    m_lastSave.start();
 }
 
-bool ProjectManager::closeCurrentDocument(bool saveChanges)
+bool ProjectManager::closeCurrentDocument(bool saveChanges, bool quit)
 {
     if (m_project && m_project->isModified() && saveChanges) {
         QString message;
@@ -180,29 +200,29 @@ bool ProjectManager::closeCurrentDocument(bool saveChanges)
             break;
         }
     }
+    if (!quit && !qApp->isSavingSession()) {
+	m_autoSaveTimer.stop();
+	pCore->window()->slotTimelineClipSelected(NULL, false);
+	pCore->monitorManager()->clipMonitor()->slotOpenClip(NULL);
+	delete m_project;
+	m_project = NULL;
+	pCore->monitorManager()->setDocument(m_project);
+	pCore->window()->m_effectStack->clear();
+	pCore->window()->m_transitionConfig->slotTransitionItemSelected(NULL, 0, QPoint(), false);
 
-    pCore->window()->slotTimelineClipSelected(NULL, false);
-    pCore->monitorManager()->clipMonitor()->slotSetClipProducer(NULL);
-    pCore->window()->m_projectList->slotResetProjectList();
-    pCore->window()->m_timelineArea->removeTab(0);
-
-    delete m_project;
-    m_project = NULL;
-    pCore->monitorManager()->setDocument(m_project);
-    pCore->window()->m_effectStack->clear();
-    pCore->window()->m_transitionConfig->slotTransitionItemSelected(NULL, 0, QPoint(), false);
-
-    delete m_trackView;
-    m_trackView = NULL;
-
+	delete m_trackView;
+	m_trackView = NULL;
+    }
     return true;
 }
 
 bool ProjectManager::saveFileAs(const QString &outputFileName)
 {
-    pCore->monitorManager()->stopActiveMonitor();
+    pCore->monitorManager()->pauseActiveMonitor();
+    // Sync document properties
+    prepareSave();
 
-    if (m_project->saveSceneList(outputFileName, pCore->monitorManager()->projectMonitor()->sceneList(), pCore->window()->m_projectList->expandedFolders()) == false) {
+    if (m_project->saveSceneList(outputFileName, pCore->monitorManager()->projectMonitor()->sceneList()) == false) {
         return false;
     }
 
@@ -276,7 +296,7 @@ void ProjectManager::openFile()
 {
     if (m_startUrl.isValid()) {
         openFile(m_startUrl);
-        m_startUrl = QUrl();
+        m_startUrl.clear();
         return;
     }
     //TODO KF5 set default location to project folder
@@ -328,7 +348,7 @@ bool ProjectManager::checkForBackupFile(const QUrl &url)
     }
 
     if (orphanedFile) {
-        if (KMessageBox::questionYesNo(pCore->window(),
+        if (KMessageBox::questionYesNo(0,
                                        i18n("Auto-saved files exist. Do you want to recover them now?"),
                                        i18n("File Recovery"),
                                        KGuiItem(i18n("Recover")), KGuiItem(i18n("Don't recover"))) == KMessageBox::Yes) {
@@ -394,7 +414,6 @@ void ProjectManager::openFile(const QUrl &url)
 void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
 {
     Q_ASSERT(m_project == NULL);
-
     if (!pCore->window()->m_timelineArea->isEnabled()) return;
     m_fileRevert->setEnabled(true);
 
@@ -403,23 +422,22 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
         delete pCore->window()->m_stopmotion;
         pCore->window()->m_stopmotion = NULL;
     }
-
     QProgressDialog progressDialog(pCore->window());
     progressDialog.setWindowTitle(i18n("Loading project"));
-    progressDialog.setLabelText(i18n("Loading project"));
     progressDialog.setCancelButton(0);
     progressDialog.setMaximum(4);
-    progressDialog.show();
     progressDialog.setValue(0);
 
+    progressDialog.setLabelText(i18n("Loading clips"));
+    progressDialog.show();
     bool openBackup;
+    m_notesPlugin->clear();
     KdenliveDoc *doc = new KdenliveDoc(stale ? QUrl::fromLocalFile(stale->fileName()) : url, QUrl::fromLocalFile(KdenliveSettings::defaultprojectfolder()), pCore->window()->m_commandStack, KdenliveSettings::default_profile(), QMap <QString, QString> (), QMap <QString, QString> (), QPoint(KdenliveSettings::videotracks(), KdenliveSettings::audiotracks()), pCore->monitorManager()->projectMonitor()->render, m_notesPlugin, &openBackup, pCore->window(), &progressDialog);
 
-    progressDialog.setValue(1);
+    progressDialog.setLabelText(i18n("Loading thumbnails"));
     progressDialog.setMaximum(4);
-    progressDialog.setLabelText(i18n("Loading project"));
+    progressDialog.setValue(1);
     progressDialog.repaint();
-
     if (stale == NULL) {
         stale = new KAutoSaveFile(url, doc);
         doc->m_autosave = stale;
@@ -435,23 +453,27 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
         stale->setParent(doc);
     }
     connect(doc, SIGNAL(progressInfo(QString,int)), pCore->window(), SLOT(slotGotProgressInfo(QString,int)));
-
+    pCore->bin()->setDocument(doc);
+    progressDialog.setLabelText(i18n("Loading timeline"));
     progressDialog.setValue(2);
     progressDialog.repaint();
 
     bool ok;
-    m_trackView = new TrackView(doc, pCore->window()->m_tracksActionCollection->actions(), &ok, pCore->window());
+    m_trackView = new Timeline(doc, pCore->window()->m_tracksActionCollection->actions(), &ok, pCore->window());
+    m_trackView->loadGuides(pCore->binController()->takeGuidesData());
+    pCore->monitorManager()->resetProfiles(doc->mltProfile(), doc->timecode());
 
     m_project = doc;
     pCore->window()->connectDocument();
     emit docOpened(m_project);
+
+    progressDialog.setLabelText(i18n("Setting monitor"));
     progressDialog.setValue(3);
     progressDialog.repaint();
 
     pCore->window()->m_timelineArea->setCurrentIndex(pCore->window()->m_timelineArea->addTab(m_trackView, QIcon::fromTheme("kdenlive"), m_project->description()));
     if (!ok) {
         pCore->window()->m_timelineArea->setEnabled(false);
-        pCore->window()->m_projectList->setEnabled(false);
         KMessageBox::sorry(pCore->window(), i18n("Cannot open file %1.\nProject is corrupted.", url.path()));
         pCore->window()->slotGotProgressInfo(QString(), -1);
         newFile(false, true);
@@ -466,6 +488,7 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
     if (openBackup) {
         slotOpenBackup(url);
     }
+    m_lastSave.start();
 }
 
 void ProjectManager::slotRevert()
@@ -519,14 +542,49 @@ void ProjectManager::slotOpenBackup(const QUrl& url)
     delete dia;
 }
 
-TrackView* ProjectManager::currentTrackView()
+Timeline* ProjectManager::currentTimeline()
 {
     return m_trackView;
 }
 
+
 KRecentFilesAction* ProjectManager::recentFilesAction()
 {
     return m_recentFilesAction;
 }
 
 
+void ProjectManager::slotStartAutoSave()
+{
+    if (m_lastSave.elapsed() > 300000) {
+        // If the project was not saved in the last 5 minute, force save
+        m_autoSaveTimer.stop();
+        slotAutoSave();
+    }
+    else {
+        m_autoSaveTimer.start(3000); // will trigger slotAutoSave() in 3 seconds
+    }
+}
+
+void ProjectManager::slotAutoSave()
+{
+    prepareSave();
+    m_project->slotAutoSave();
+    m_lastSave.start();
+}
+
+void ProjectManager::prepareSave()
+{
+    pCore->binController()->saveDocumentProperties(m_project->documentProperties(), m_trackView->projectView()->guidesData());
+    QString projectNotes = m_project->documentNotes();
+    pCore->binController()->saveProperty("kdenlive:documentnotes", projectNotes);
+    pCore->binController()->saveProperty("kdenlive:clipgroups", m_project->groupsXml());
+}
+
+
+void ProjectManager::slotResetProfiles()
+{
+    m_project->resetProfile();
+    pCore->monitorManager()->resetProfiles(m_project->mltProfile(), m_project->timecode());
+    pCore->monitorManager()->updateScopeSource();
+}
