@@ -30,6 +30,8 @@
 #include "doc/kdenlivedoc.h"
 
 #include <QDebug>
+#include <QMimeData>
+#include <QTreeWidget>
 #include "klocalizedstring.h"
 
 TransitionSettings::TransitionSettings(Monitor *monitor, QWidget* parent) :
@@ -44,18 +46,20 @@ TransitionSettings::TransitionSettings(Monitor *monitor, QWidget* parent) :
     vbox1->setSpacing(0);
     vbox1->addWidget(m_effectEdit);
     frame->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
-    connect(m_effectEdit, SIGNAL(seekTimeline(int)), this, SLOT(slotSeekTimeline(int)));
-    connect(m_effectEdit, SIGNAL(importClipKeyframes()), this, SIGNAL(importClipKeyframes()));
-    
+    connect(m_effectEdit, &EffectStackEdit::seekTimeline, this, &TransitionSettings::slotSeekTimeline);
+    connect(m_effectEdit, &EffectStackEdit::importClipKeyframes, this, &TransitionSettings::importClipKeyframes);
+
     setEnabled(false);
+    setAcceptDrops(true);
 
     QList<QStringList> transitionsList;
     int max = MainWindow::transitions.effectNames().count();
     QStringList transitionInfo;
-    int ix = 0;
+    int ix = 1;
 
-    for (; ix < max; ++ix) {
+    for (; ix <= max; ++ix) {
         transitionInfo = MainWindow::transitions.effectIdInfo(ix);
+        if (transitionInfo.isEmpty()) continue;
         transitionInfo << QString::number(ix);
         transitionsList.append(transitionInfo);
     }
@@ -73,11 +77,44 @@ TransitionSettings::TransitionSettings(Monitor *monitor, QWidget* parent) :
     connect(m_effectEdit, SIGNAL(parameterChanged(QDomElement,QDomElement,int)), this , SLOT(slotUpdateEffectParams(QDomElement,QDomElement)));
 }
 
+void TransitionSettings::dragEnterEvent(QDragEnterEvent * event ) {
+    if (event->mimeData()->hasFormat("application/x-qabstractitemmodeldatalist")) {
+        event->setDropAction(Qt::CopyAction);
+        event->setAccepted(true);
+    }
+    else QWidget::dragEnterEvent(event);
+}
+
+void TransitionSettings::dropEvent( QDropEvent* event ) 
+{
+if (event->mimeData()->hasFormat("application/x-qabstractitemmodeldatalist"))
+        {
+                QTreeWidget *tree = dynamic_cast<QTreeWidget *>(event->source());
+ 
+                QByteArray itemData = event->mimeData()->data("application/x-qabstractitemmodeldatalist");
+                QDataStream stream(&itemData, QIODevice::ReadOnly);
+ 
+                int r, c;
+                QMap<int, QVariant> v;
+                stream >> r >> c >> v;
+ 
+                QTreeWidgetItem *item = tree->topLevelItem(r);
+ 
+                if( item && item->columnCount() == 2)
+                {
+                    QMap <QString, QString> data;
+                    data.insert(item->text(0), item->text(1));
+                    emit importClipKeyframes(TransitionWidget, data);
+                }
+        }
+ 
+}
+
 void TransitionSettings::updateProjectFormat()
 {
     KdenliveDoc *project = pCore->projectManager()->current();
-    m_effectEdit->updateProjectFormat(project->mltProfile(), project->timecode());
-    m_tracks = project->tracksList();
+    m_effectEdit->updateProjectFormat(project->timecode());
+    m_tracks = pCore->projectManager()->currentTimeline()->getTracksInfo();
     updateTrackList();
 }
 
@@ -99,9 +136,8 @@ void TransitionSettings::updateTrackList()
     QIcon videoIcon = QIcon::fromTheme("kdenlive-show-video");
     QIcon audioIcon = QIcon::fromTheme("kdenlive-show-audio");
     for (int i = limit; i < m_tracks.count(); ++i) {
-        int ix = m_tracks.count() - i - 1;
-        transitionTrack->addItem(m_tracks.at(ix).type == VideoTrack ? videoIcon : audioIcon,
-                                 m_tracks.at(ix).trackName.isEmpty() ? QString::number(i) : m_tracks.at(ix).trackName + " (" + QString::number(i) + ')',
+        transitionTrack->addItem(m_tracks.at(i).type == VideoTrack ? videoIcon : audioIcon,
+                                 m_tracks.at(i).trackName.isEmpty() ? QString::number(i) : m_tracks.at(i).trackName,
                                  m_tracks.count() - i);
     }
     transitionTrack->addItem(i18n("Black"), 0);
@@ -253,6 +289,7 @@ void TransitionSettings::slotCheckMonitorPosition(int renderPos)
         if (renderPos >= m_usedTransition->startPos().frames(KdenliveSettings::project_fps()) && renderPos < m_usedTransition->endPos().frames(KdenliveSettings::project_fps())) {
             if (!m_effectEdit->monitor()->effectSceneDisplayed()) {
                 m_effectEdit->monitor()->slotShowEffectScene(true);
+                m_effectEdit->initEffectScene(renderPos - m_usedTransition->startPos().frames(KdenliveSettings::project_fps()));
             }
         } else {
             m_effectEdit->monitor()->slotShowEffectScene(false);
