@@ -32,11 +32,12 @@
 #include <QWaitCondition>
 
 #include "doc/kdenlivedoc.h"
-#include "doc/docclipbase.h"
 #include "timeline/guide.h"
 #include "effectslist/effectslist.h"
 #include "timeline/customtrackscene.h"
 
+class Timeline;
+class ClipController;
 class ClipItem;
 class AbstractClipItem;
 class AbstractGroupItem;
@@ -48,7 +49,7 @@ class CustomTrackView : public QGraphicsView
     Q_OBJECT
 
 public:
-    CustomTrackView(KdenliveDoc *doc, CustomTrackScene* projectscene, QWidget *parent = 0);
+    CustomTrackView(KdenliveDoc *doc, Timeline* timeline, CustomTrackScene* projectscene, QWidget *parent = 0);
     virtual ~ CustomTrackView();
     virtual void mousePressEvent(QMouseEvent * event);
     virtual void mouseReleaseEvent(QMouseEvent * event);
@@ -56,7 +57,7 @@ public:
     virtual void mouseDoubleClickEvent(QMouseEvent *event);
     void addTrack(const TrackInfo &type, int ix = -1);
     void removeTrack(int ix);
-    /** @brief Makes the document use new track infos (name, type, ...). */
+    /** @brief Makes the document use new track info (name, type, ...). */
     void configTracks(const QList<TrackInfo> &trackInfos);
     int cursorPos() const;
     void checkAutoScroll();
@@ -71,14 +72,12 @@ public:
     /** move transition, startPos = (old start, old end), endPos = (new start, new end) */
     void moveTransition(const ItemInfo &start, const ItemInfo &end, bool refresh);
     void resizeClip(const ItemInfo &start, const ItemInfo &end, bool dontWorry = false);
-    void addClip(QDomElement xml, const QString &clipId, ItemInfo info, EffectsList list = EffectsList(), bool overwrite = false, bool push = false, bool refresh = true);
+    void addClip(const QString &clipId, ItemInfo info, EffectsList list, PlaylistState::ClipState state, bool refresh = true);
     void deleteClip(ItemInfo info, bool refresh = true);
-    void slotDeleteClipMarker(const QString &comment, const QString &id, const GenTime &position);
-    void slotDeleteAllClipMarkers(const QString &id);
     void addMarker(const QString &id, const CommentedTime &marker);
     void addData(const QString &id, const QString &key, const QString &data);
     void setScale(double scaleFactor, double verticalScale);
-    void deleteClip(const QString &clipId);
+    void deleteClip(const QString &clipId, QUndoCommand *deleteCommand);
     /** @brief An effect was dropped on @param clip */
     void slotDropEffect(ClipItem *clip, QDomElement effect, GenTime pos, int track);
     /** @brief Add effect to current clip */
@@ -114,7 +113,10 @@ public:
     QList<ItemInfo> findId(const QString &clipId);
     void clipStart();
     void clipEnd();
-    void doChangeClipSpeed(ItemInfo info, const ItemInfo &speedIndependantInfo, const double speed, const double oldspeed, int strobe, const QString &id);
+    void doChangeClipSpeed(ItemInfo info, const ItemInfo &speedIndependantInfo, const double speed, int strobe, const QString &id);
+    /** @brief Every command added to the undo stack automatically triggers a document change event.
+     *  This function should only be called when changing a document setting or another function that 
+     *  is not integrated in the undo / redo system */
     void setDocumentModified();
     void setInPoint();
     void setOutPoint();
@@ -158,15 +160,14 @@ public:
     * @param split Split or unsplit */
     void doSplitAudio(const GenTime &pos, int track, EffectsList effects, bool split);
     /** @brief Sets the clip type (av, video only, audio only) of the current selection. */
-    void setClipType(bool videoOnly, bool audioOnly);
-    void doChangeClipType(const GenTime &pos, int track, bool videoOnly, bool audioOnly);
+    void setClipType(PlaylistState::ClipState state);
+    void doChangeClipType(const GenTime &pos, int track, PlaylistState::ClipState state);
     int hasGuide(int pos, int offset);
     void reloadTransitionLumas();
     void updateProjectFps();
     double fps() const;
     int selectedTrack() const;
     QStringList selectedClips() const;
-    QList<ClipItem *> selectedClipItems() const;
     /** @brief Checks whether an item can be inserted (make sure it does not overlap another item) */
     bool canBePastedTo(ItemInfo info, int type) const;
 
@@ -186,7 +187,7 @@ public:
     * @param out The outpoint of the clip (crop from end)
     *
     * Inserts at the position of timeline cursor and selected track. */
-    void insertClipCut(DocClipBase *clip, int in, int out);
+    void insertClipCut(const QString &id, int in, int out);
     void clearSelection(bool emitInfo = true);
     void editItemDuration();
     void buildGuidesMenu(QMenu *goMenu) const;
@@ -207,10 +208,7 @@ public:
     
     /** @brief Returns frame number of current mouse position. */
     int getMousePos() const;
-    
-    /** @brief Get effect parameters ready for MLT*/
-    static void adjustEffectParameters(EffectsParameterList &parameters, QDomNodeList params, MltVideoProfile profile, const QString &prefix = QString());
-    
+
     void completeSpaceOperation(int track, GenTime &timeOffset);
     void spaceToolMoveToSnapPos(double snappedPos);
     void createRectangleSelection(QMouseEvent * event);
@@ -220,8 +218,8 @@ public:
     void createGroupForSelectedItems(QList<QGraphicsItem *> &selection);
     void selectItemsRightOfFrame(int frame);
     void resetSelectionGroup(bool selectItems = true);
-    /** @brief We are performing a timeline operation. */
-    void setOperation(OperationType op);
+    /** @brief Returns all infos necessary to save guides. */
+    QMap <double, QString> guidesData() const;
 
 public slots:
     /** @brief Send seek request to MLT. */
@@ -229,7 +227,6 @@ public slots:
     /** @brief Move timeline cursor to new position. */
     void setCursorPos(int pos);
     void moveCursorPos(int delta);
-    void updateCursorPos();
     void slotDeleteEffect(ClipItem *clip, int track, QDomElement effect, bool affectGroup = true);
     void slotChangeEffectState(ClipItem *clip, int track, QList <int> effectIndexes, bool disable);
     void slotChangeEffectPosition(ClipItem *clip, int track, QList <int> currentPos, int newPos);
@@ -240,21 +237,12 @@ public slots:
     void slotAddTransition(ClipItem* clip, ItemInfo transitionInfo, int endTrack, QDomElement transition = QDomElement());
     void slotAddTransitionToSelectedClips(QDomElement transition);
     void slotTransitionUpdated(Transition *, QDomElement);
-    void slotSwitchTrackAudio(int ix);
-    void slotSwitchTrackVideo(int ix);
-    void slotSwitchTrackLock(int ix);
+    void slotSwitchTrackAudio(int ix, bool enable);
+    void slotSwitchTrackVideo(int ix, bool enable);
+    void slotSwitchTrackLock(int ix, bool enable);
     void slotUpdateClip(const QString &clipId, bool reload = true);
-    
-    /** @brief Add extra data to a clip. */
-    void slotAddClipExtraData(const QString &id, const QString &key, const QString &data = QString(), QUndoCommand *groupCommand = 0);
-    /** @brief Creates a AddClipCommand to add, edit or delete a marker.
-     * @param id Id of the marker's clip
-     * @param t Position of the marker
-     * @param c Comment of the marker */
-    void slotAddClipMarker(const QString &id, QList <CommentedTime> newMarker, QUndoCommand *groupCommand = 0);
-    void slotLoadClipMarkers(const QString &id);
-    void slotSaveClipMarkers(const QString &id);
-    bool addGuide(const GenTime &pos, const QString &comment);
+
+    bool addGuide(const GenTime &pos, const QString &comment, bool loadingProject = false);
 
     /** @brief Shows a dialog for adding a guide.
      * @param dialog (default = true) false = do not show the dialog but use current position as position and comment */
@@ -276,7 +264,7 @@ public slots:
     void slotDeleteTrack(int ix);
     /** @brief Shows the configure tracks dialog. */
     void slotConfigTracks(int ix);
-    void clipNameChanged(const QString &id, const QString &name);
+    void clipNameChanged(const QString &id);
     void slotTrackUp();
     void slotTrackDown();
     void slotSelectTrack(int ix);
@@ -306,11 +294,11 @@ public slots:
     void updateSnapPoints(AbstractClipItem *selected, QList <GenTime> offsetList = QList <GenTime> (), bool skipSelectedItems = false);
     
     void slotAddEffect(ClipItem *clip, const QDomElement &effect);
-    void slotImportClipKeyframes(GraphicsRectItem type);
+    void slotImportClipKeyframes(GraphicsRectItem type, QMap<QString, QString> data = QMap<QString, QString>());
 
     /** @brief Move playhead to mouse curser position if defined key is pressed */
     void slotAlignPlayheadToMousePos();
-    
+
     void slotInfoProcessingFinished();
     void slotAlignClip(int, int, int);
 
@@ -333,6 +321,7 @@ private:
     int m_projectDuration;
     int m_cursorPos;
     KdenliveDoc *m_document;
+    Timeline *m_timeline;
     CustomTrackScene *m_scene;
     QGraphicsLineItem *m_cursorLine;
     ItemInfo m_dragItemInfo;
@@ -355,7 +344,6 @@ private:
     ClipItem *getClipItemAtMiddlePoint(int pos, int track);
     ClipItem *getClipItemAtEnd(GenTime pos, int track);
     ClipItem *getClipItemAtStart(GenTime pos, int track);
-    Transition *getTransitionItem(TransitionInfo info);
     Transition *getTransitionItemAt(int pos, int track);
     Transition *getTransitionItemAt(GenTime pos, int track);
     Transition *getTransitionItemAtEnd(GenTime pos, int track);
@@ -398,7 +386,6 @@ private:
     QMutex m_selectionMutex;
     QMutex m_mutex;
     QWaitCondition m_producerNotReady;
-    KStatefulBrush m_activeTrackBrush;
 
     AudioCorrelation *m_audioCorrelator;
     ClipItem *m_audioAlignmentReference;
@@ -461,9 +448,6 @@ private:
     * @param cutPos The absolute position of the cut */
     void razorGroup(AbstractGroupItem *group, GenTime cutPos);
 
-    /** @brief Gets the effect parameters that will be passed to Mlt. */
-    EffectsParameterList getEffectArgs(const QDomElement &effect);
-
     /** @brief Update Tracknames to fit again after track was added/deleted.
      * @param track Number of track which was added/deleted
      * @param added true = track added, false = track deleted
@@ -488,10 +472,11 @@ private:
     
     /** @brief Prepare an add clip command for an effect */
     void processEffect(ClipItem *item, QDomElement effect, int offset, QUndoCommand *effectCommand);
+    /** @brief Reload all clips and transitions from MLT's playlist */
+    void reloadTimeline();
 
 private slots:
     void slotRefreshGuides();
-    void slotEnableRefresh();
     void slotCheckMouseScrolling();
     void slotEditTimeLineGuide();
     void slotDeleteTimeLineGuide();
@@ -506,6 +491,11 @@ private slots:
     void slotRefreshThumbs(const QString &id, bool resetThumbs);
     /** @brief A Filter job producer results. */
     void slotGotFilterJobResults(const QString &id, int startPos, int track, stringMap filterParams, stringMap extra);
+    /** @brief Replace a producer in all tracks (for example when proxying a clip). */
+    void slotReplaceTimelineProducer(const QString &id);
+    void slotPrepareTimelineReplacement(const QString &id);
+    /** @brief Update a producer in all tracks (for example when an effect changed). */
+    void slotUpdateTimelineProducer(const QString &id);
 
 
 signals:
@@ -522,10 +512,8 @@ signals:
     void trackHeightChanged();
     void tracksChanged();
     void displayMessage(const QString &, MessageType);
-    void showClipFrame(DocClipBase *, QPoint, bool, const int);
     void doTrackLock(int, bool);
-    void updateClipMarkers(DocClipBase *);
-    void updateClipExtraData(DocClipBase *);
+    void updateClipMarkers(ClipController*);
     void updateTrackHeaders();
     void playMonitor();
     /** @brief Monitor document changes (for example the presence of audio data in timeline for export widget.*/
@@ -534,9 +522,11 @@ signals:
     /** @brief Update the track effect button that shows if a track has effects or not.*/
     void updateTrackEffectState(int);
     /** @brief Cursor position changed, repaint ruler.*/
-    void updateRuler();
+    void updateRuler(int pos);
     /** @brief Send data from a clip to be imported as keyframes for effect / transition.*/
     void importKeyframes(GraphicsRectItem type, const QString&, int maximum);
+    /** @brief Guides were changed, inform render widget*/
+    void guidesUpdated();
 };
 
 #endif
