@@ -30,6 +30,7 @@
 #include "effectslist/effectslist.h"
 class GenTime;
 class CustomTrackView;
+class Timeline;
 
 class AddEffectCommand : public QUndoCommand
 {
@@ -45,49 +46,20 @@ private:
     bool m_doIt;
 };
 
-class AddExtraDataCommand : public QUndoCommand
-{
-public:
-    AddExtraDataCommand(CustomTrackView *view, const QString&id, const QString&key, const QString &oldData, const QString &newData, QUndoCommand * parent = 0);
-    void undo();
-    void redo();
-private:
-    CustomTrackView *m_view;
-    QString m_oldData;
-    QString m_newData;
-    QString m_key;
-    QString m_id;
-};
-
-class AddMarkerCommand : public QUndoCommand
-{
-public:
-    AddMarkerCommand(CustomTrackView *view, const CommentedTime &oldMarker, const CommentedTime &newMarker, const QString &id, QUndoCommand * parent = 0);
-    void undo();
-    void redo();
-private:
-    CustomTrackView *m_view;
-    CommentedTime m_oldMarker;
-    CommentedTime m_newMarker;
-    QString m_id;
-};
-
 class AddTimelineClipCommand : public QUndoCommand
 {
 public:
-    AddTimelineClipCommand(CustomTrackView *view, const QDomElement &xml, const QString &clipId, const ItemInfo &info, const EffectsList &effects, bool overwrite, bool push, bool doIt, bool doRemove, QUndoCommand * parent = 0);
+    AddTimelineClipCommand(CustomTrackView *view, const QString &clipId, const ItemInfo &info, const EffectsList &effects, PlaylistState::ClipState state, bool doIt, bool doRemove, QUndoCommand * parent = 0);
     void undo();
     void redo();
 private:
     CustomTrackView *m_view;
+    QString m_clipId;
     ItemInfo m_clipInfo;
     EffectsList m_effects;
-    QString m_clipId;
-    QDomElement m_xml;
+    PlaylistState::ClipState m_state;
     bool m_doIt;
     bool m_remove;
-    bool m_overwrite;
-    bool m_push;
 };
 
 class AddTrackCommand : public QUndoCommand
@@ -122,17 +94,15 @@ private:
 class ChangeClipTypeCommand : public QUndoCommand
 {
 public:
-    ChangeClipTypeCommand(CustomTrackView *view, const int track, const GenTime &pos, bool videoOnly, bool audioOnly, bool originalVideo, bool originalAudio, QUndoCommand * parent = 0);
+    ChangeClipTypeCommand(CustomTrackView *view, const int track, const GenTime &pos, PlaylistState::ClipState state, PlaylistState::ClipState originalState, QUndoCommand * parent = 0);
     void undo();
     void redo();
 private:
     CustomTrackView *m_view;
     const GenTime m_pos;
     const int m_track;
-    bool m_videoOnly;
-    bool m_audioOnly;
-    bool m_originalVideoOnly;
-    bool m_originalAudioOnly;
+    PlaylistState::ClipState m_state;
+    PlaylistState::ClipState m_originalState;
 };
 
 class ChangeEffectStateCommand : public QUndoCommand
@@ -154,7 +124,7 @@ private:
 class ChangeSpeedCommand : public QUndoCommand
 {
 public:
-    ChangeSpeedCommand(CustomTrackView *view, const ItemInfo &info, const ItemInfo &speedIndependantInfo, double old_speed, double new_speed, int old_strobe, int new_strobe, const QString &clipId, QUndoCommand * parent = 0);
+    ChangeSpeedCommand(CustomTrackView *view, const ItemInfo &info, const ItemInfo &speedIndependantInfo, double new_speed, int old_strobe, int new_strobe, const QString &clipId, QUndoCommand * parent = 0);
     void undo();
     void redo();
 private:
@@ -162,7 +132,6 @@ private:
     ItemInfo m_clipInfo;
     ItemInfo m_speedIndependantInfo;
     QString m_clipId;
-    double m_old_speed;
     double m_new_speed;
     int m_old_strobe;
     int m_new_strobe;
@@ -171,13 +140,16 @@ private:
 class ConfigTracksCommand : public QUndoCommand
 {
 public:
-    ConfigTracksCommand(CustomTrackView *view, const QList <TrackInfo> &oldInfos, const QList <TrackInfo> &newInfos, QUndoCommand * parent = 0);
+    ConfigTracksCommand(Timeline *timeline, int track, const QString &oldName, const QString &newName, int oldState = -1, int newState = -1, QUndoCommand* parent = 0);
     void undo();
     void redo();
 private:
-    CustomTrackView *m_view;
-    QList <TrackInfo> m_oldInfos;
-    QList <TrackInfo> m_newInfos;
+    Timeline *m_timeline;
+    int m_ix;
+    QString m_oldName;
+    QString m_newName;
+    int m_oldState;
+    int m_newState;
 };
 
 class EditEffectCommand : public QUndoCommand
